@@ -18,14 +18,14 @@
 #' data("simu_data")
 #' q = f_to_srvf(simu_data$f,simu_data$time)
 #' f = srsf_to_f(q,simu_data$time,simu_data$f[1,])
-srsf_to_f <- function(q,time,f0=0.0){
+srsf_to_f<- function(q,time,f0=0.0){
     if (is.null(dim(q))){
         integrand = q*abs(q)
         f = f0 + cumtrapz(time, integrand)
     } else {
         M = nrow(q);
         N = ncol(q);
-        if (is.null(dim(f0))){
+        if (length(f0)==0){
             f0 = rep(0,N)
         }
         f = matrix(0,M,N)
